@@ -50,11 +50,7 @@ void DomParser::parse_file(const Glib::ustring& filename)
 
   if(!context_)
   {
-    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw internal_error("Couldn't create parsing context\n" + format_xml_error());
-    #else
-    return;
-    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   if(context_->directory == 0)
@@ -78,11 +74,7 @@ void DomParser::parse_memory_raw(const unsigned char* contents, size_type bytes_
 
   if(!context_)
   {
-    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw internal_error("Couldn't create parsing context\n" + format_xml_error());
-    #else
-    return;
-    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   parse_context();
@@ -104,11 +96,7 @@ void DomParser::parse_context()
 
   if(!context_)
   {
-    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw internal_error("Context not initialized\n" + format_xml_error());
-    #else
-    return;
-    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   xmlParseDocument(context_);
@@ -121,11 +109,7 @@ void DomParser::parse_context()
   {
     release_underlying(); //Free doc_ and context_
 
-    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw parse_error(error_str);
-    #else
-    return;
-    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   doc_ = new Document(context_->myDoc);
@@ -157,11 +141,7 @@ void DomParser::parse_stream(std::istream& in)
 
   if(!context_)
   {
-    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw internal_error("Couldn't create parsing context\n" + format_xml_error());
-    #else
-    return;
-    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   initialize_context();
@@ -187,11 +167,7 @@ void DomParser::parse_stream(std::istream& in)
   {
     release_underlying(); //Free doc_ and context_
 
-    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw parse_error(error_str);
-    #else
-    return;
-    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   doc_ = new Document(context_->myDoc);
