@@ -38,7 +38,7 @@ TextReader::TextReader(
 	size_type size,
 	const Glib::ustring& uri)
 	: propertyreader(new PropertyReader(*this)), 
-	  impl_( xmlReaderForMemory ((const char*)data, size, uri.c_str(), nullptr, 0) ),
+	  impl_( xmlReaderForMemory ((const char*)data, size, uri.c_str(), 0, 0) ),
     severity_( 0 )
 {
   if( ! impl_ )
@@ -106,7 +106,7 @@ int TextReader::get_attribute_count() const
 Glib::ustring TextReader::get_base_uri() const
 {
   return propertyreader->String(
-      xmlTextReaderBaseUri(impl_), true);
+      xmlTextReaderBaseUri(impl_));
 }
 
 int TextReader::get_depth() const
@@ -293,7 +293,7 @@ void TextReader::set_parser_property(
 
 Node* TextReader::get_current_node()
 {
-  auto node = xmlTextReaderCurrentNode(impl_);
+  xmlNodePtr node = xmlTextReaderCurrentNode(impl_);
   if(node)
   {
     Node::create_wrapper(node);
@@ -301,19 +301,27 @@ Node* TextReader::get_current_node()
   }
     
   check_for_exceptions();
-  return nullptr;
+  return 0;
 }
 
 const Node* TextReader::get_current_node() const
 {
-  return const_cast<TextReader*>(this)->get_current_node();
+  xmlNodePtr node = xmlTextReaderCurrentNode(impl_);
+  if(node)
+  {
+    Node::create_wrapper(node);
+    return static_cast<Node*>(node->_private);
+  }
+
+  check_for_exceptions();
+  return 0;
 }
 
 /*
 TODO: add a private constructor to Document.
 Document* TextReader::CurrentDocument()
 {
-  auto doc = xmlTextReaderCurrentDoc(impl_);
+  xmlDocPtr doc = xmlTextReaderCurrentDoc(impl_);
   if(doc)
     return new Document(doc);
 }
@@ -321,7 +329,8 @@ Document* TextReader::CurrentDocument()
 
 Node* TextReader::expand()
 {
-  auto node = xmlTextReaderExpand(impl_);
+  xmlNodePtr node = xmlTextReaderExpand(impl_);
+  if(node)
   if(node)
   {
     Node::create_wrapper(node);
@@ -329,7 +338,7 @@ Node* TextReader::expand()
   }
     
   check_for_exceptions();
-  return nullptr;
+  return 0;
 }
 
 bool TextReader::next()
@@ -346,8 +355,8 @@ bool TextReader::is_valid() const
 
 void TextReader::setup_exceptions()
 {
-  xmlTextReaderErrorFunc func = nullptr;
-  void* arg = nullptr; 
+  xmlTextReaderErrorFunc func = 0;
+  void* arg = 0; 
 
   // We respect any other error handlers already setup:
   xmlTextReaderGetErrorHandler(impl_, &func, &arg);
@@ -360,7 +369,7 @@ void TextReader::setup_exceptions()
 
 void TextReader::on_libxml_error(void* arg, const char* msg, int severity, void* /* locator */)
 {
-  auto ths = (TextReader*)arg;
+  TextReader* ths = (TextReader*)arg;
   ths->severity_ = severity;
   ths->error_ = msg ? msg : "unknown parse error";
 }
@@ -370,11 +379,12 @@ void TextReader::check_for_exceptions() const
   if( severity_ == 0 )
     return;
     
-  auto ths = const_cast<TextReader*>(this);
+  TextReader* ths = const_cast<TextReader*>(this);
 
   int severity = severity_;
   ths->severity_ = 0;
 
+  //TODO: Offer an alternative when not using exceptions?
   if( severity == XML_PARSER_SEVERITY_ERROR )
     throw parse_error(error_);
   else if( severity == XML_PARSER_SEVERITY_VALIDITY_ERROR )
@@ -394,7 +404,7 @@ bool TextReader::PropertyReader::Bool(int value)
   if(value == -1)
     owner_.check_for_exceptions();
     
-  return value > 0;
+  return value;
 }
 
 char TextReader::PropertyReader::Char(int value)
@@ -407,7 +417,7 @@ Glib::ustring TextReader::PropertyReader::String(xmlChar* value, bool free)
 {
   owner_.check_for_exceptions();
   
-  if (!value)
+  if(value == (xmlChar *)0)
     return Glib::ustring();
     
   const Glib::ustring result = (char *)value;
@@ -422,7 +432,7 @@ Glib::ustring TextReader::PropertyReader::String(xmlChar const* value)
 {
   owner_.check_for_exceptions();
 
-  if (!value)
+  if(value == (xmlChar *)0)
     return Glib::ustring();
 
   return (const char*)value;
